@@ -3,23 +3,28 @@ save_drug_sub <-
            df,
            table_name,
            save_table_only = FALSE,
-           field.types = NULL,
+           field_types = NULL,
            primary_key = NULL,
            foreign_key = NULL,
            ref_table = "drug(primary_key)") {
-    if (grepl("MariaDB", class(con))) {
-      field.types <- unlist(field.types[1])
+    if (is_empty(df)) {
+      return()
     }
+
+    if (grepl("MariaDB", class(con))) {
+      field_types <- unlist(field_types[1])
+    }
+
     # store drug sub_Table in db
     dbWriteTable(
       conn = con,
       value = df,
       name = table_name,
-      field.types = field.types,
+      field_types = field_types,
       overwrite = TRUE
     )
 
-    if (!grepl("MariaDB", class(con))) {
+    if (grepl("SQLServer", class(con))) {
       for (key in primary_key) {
         dbExecute(
           conn = con,
@@ -32,23 +37,23 @@ save_drug_sub <-
           )
         )
       }
-    }
 
-    if (!save_table_only) {
-      # add primary key of drug table
-      if (!is.null(primary_key)) {
-        dbExecute(
-          conn = con,
-          statement = paste(
-            "Alter table",
-            table_name,
-            "add primary key(",
-            paste(primary_key, collapse = ","),
-            ");"
+      if (!save_table_only) {
+        # add primary key of drug table
+        if (!is.null(primary_key)) {
+          dbExecute(
+            conn = con,
+            statement = paste(
+              "Alter table",
+              table_name,
+              "add primary key(",
+              paste(primary_key, collapse = ","),
+              ");"
+            )
           )
-        )
-
+        }
       }
+
       # add foreign key of drug table
       if (!is.null(foreign_key)) {
         dbExecute(
@@ -58,7 +63,9 @@ save_drug_sub <-
             table_name,
             "ADD CONSTRAINT",
             paste("FK_", table_name,
-                  "_drug", sep = ""),
+              "_drug",
+              sep = ""
+            ),
             paste(
               "FOREIGN KEY (",
               foreign_key,
@@ -69,6 +76,5 @@ save_drug_sub <-
           )
         )
       }
-
     }
   }
